@@ -604,4 +604,14 @@ class mDastBase:
     def get_issue_info(self, issue_id):
         return requests.get(f'{self.url}/dast_issues/{issue_id}/',
                             headers=self.headers,
-                            verify=False)
\ No newline at end of file
+                            verify=False)
+
+    def get_localization_issue_data_keys(self):
+        return requests.get(f'{self.url}/localization/issue_data_keys',
+                            headers=self.headers,
+                            verify=False)
+
+    def get_modules(self):
+        return requests.get(f'{self.url}/modules/',
+                            headers=self.headers,
+                            verify=False)
